import json
import unittest

from lesson3.common.utils import send_message, get_message
from lesson3.common.variables import ENCODING, ACTION, TIME, USER, PRESENCE, ACCOUNT_NAME, RESPONSE, ERROR


class TestSocket:
    def __init__(self, test_dict):
        self.test_dict = test_dict
        self.encoded_msg = None
        self.received_msg = None

    def send(self, msg_to_send):
        json_test_msg = json.dumps(self.test_dict)
        self.encoded_msg = json_test_msg.encode(ENCODING)
        self.received_msg = msg_to_send

    def recv(self, max_len):
        json_test_msg = json.dumps(self.test_dict)
        return json_test_msg.encode(ENCODING)


class TestUtils(unittest.TestCase):
    def setUp(self) -> None:
        self.test_dict_send = {
            ACTION: PRESENCE,
            TIME: 111111.111111,
            USER: {
                ACCOUNT_NAME: 'test_user'
            }
        }
        self.test_recv_ok = {RESPONSE: 200}
        self.test_recv_err = {
            RESPONSE: 400,
            ERROR: 'Bad request'
        }
        self.test_socket = TestSocket(self.test_dict_send)
        self.send_msg = send_message
        self.get_msg = get_message

    def test_send_msg(self):
        self.send_msg(self.test_socket, self.test_dict_send)
        self.assertEqual(self.test_socket.encoded_msg, self.test_socket.received_msg)

    def test_send_msg_raise(self):
        self.send_msg(self.test_socket, self.test_dict_send)
        self.assertRaises(TypeError, self.send_msg, self.test_socket, 'wrong_dictionary')

    def test_get_message_ok(self):
        self.test_socket.test_dict = self.test_recv_ok
        self.assertEqual(self.get_msg(self.test_socket), self.test_recv_ok)

    def test_get_message_err(self):
        self.test_socket.test_dict = self.test_recv_err
        self.assertEqual(self.get_msg(self.test_socket), self.test_recv_err)


if __name__ == '__main__':
    unittest.main()



class ServerError(Exception):
    '''
       Класс - исключение, для обработки ошибок сервера.
       При генерации требует строку с описанием ошибки,
       полученную с сервера.
       '''
    def __init__(self, text):
        self.text = text

    def __str__(self):
        return self.text



import sys
import unittest
from unittest.mock import patch

from lesson3.client import ChatClient
from lesson3.common.variables import TIME, ACTION, PRESENCE, USER, ACCOUNT_NAME, RESPONSE, ERROR


class TestClient(unittest.TestCase):
    def setUp(self) -> None:
        self.client = ChatClient()
        self.test = self.client.create_presence()
        self.request_ans = self.client.process_ans
        self.address = self.client.get_server_address
        self.err = {
            RESPONSE: 400,
            ERROR: 'Bad request'
        }
        self.ok = {
            RESPONSE: 200
        }

    def test_presense(self):
        self.test[TIME] = 1.1
        self.assertEqual(self.test, {ACTION: PRESENCE, TIME: 1.1, USER: {ACCOUNT_NAME: 'Guest'}})

    def test_200(self):
        self.assertEqual(self.request_ans(self.ok), '200: ok')

    def test_400(self):
        self.assertEqual(self.request_ans(self.err), '400: Bad request')

    def test_no_response(self):
        self.assertRaises(ValueError, self.request_ans, {ERROR: 'Bad request'})


if __name__ == '__main__':
    unittest.main()



import unittest

from lesson3.common.variables import RESPONSE, ERROR, ACTION, PRESENCE, TIME, USER, ACCOUNT_NAME, \
    RESPONDEFAULT_IP_ADDRESS
from lesson3.server import ChatServer


class TestServer(unittest.TestCase):
    def setUp(self) -> None:
        self.err = {
            RESPONDEFAULT_IP_ADDRESS: 400,
            ERROR: 'Bad Request'
        }
        self.ok = {
            RESPONSE: 200
        }

        self.server = ChatServer()
        self.client_msg = self.server.process_client_message

    def test_ok(self):
        self.assertEqual(self.client_msg({ACTION: PRESENCE, TIME: 1.1, USER: {ACCOUNT_NAME: 'Guest'}}), self.ok)

    def test_no_action(self):
        self.assertEqual(self.client_msg({TIME: 1.1, USER: {ACCOUNT_NAME: 'Guest'}}), self.err)

    def test_wrong_action(self):
        self.assertEqual(self.client_msg({ACTION: 'wrong', TIME: 1.1, USER: {ACCOUNT_NAME: 'Guest'}}), self.err)

    def test_no_time(self):
        self.assertEqual({ACTION: PRESENCE, USER: {ACCOUNT_NAME: 'Guest'}},
                         {ACTION: PRESENCE, USER: {ACCOUNT_NAME: 'Guest'}})

    def test_no_user(self):
        self.assertEqual(self.client_msg({ACTION: PRESENCE, TIME: 1.1}), self.err)

    def test_unknown_user(self):
        self.assertEqual(self.client_msg({ACTION: 'wrong', TIME: 1.1, USER: {ACCOUNT_NAME: 'anonim'}}), self.err)


if __name__ == '__main__':
    unittest.main()



import socket
import logging
import sys

sys.path.append('../')
import lesson3.logs.config_client_log
import lesson3.logs.config_server_log

if sys.argv[0].find('client_dist') == -1:
    logger = logging.getLogger('server_dist')
else:
    logger = logging.getLogger('client_dist')


def log(func_to_log):
    '''
        Декоратор, выполняющий логирование вызовов функций.
        Сохраняет события типа debug, содержащие
        информацию о имени вызываемой функиции, параметры с которыми
        вызывается функция, и модуль, вызывающий функцию.
        '''
    def log_saver(*args, **kwargs):
        logger.debug(
            f'Была вызвана функция {func_to_log.__name__} c параметрами {args} , {kwargs}. '
            f'Вызов из модуля {func_to_log.__module__}')
        ret = func_to_log(*args, **kwargs)
        return ret

    return log_saver


def login_required(func):
    '''
      Декоратор, проверяющий, что клиент авторизован на сервере.
      Проверяет, что передаваемый объект сокета находится в
      списке авторизованных клиентов.
      За исключением передачи словаря-запроса
      на авторизацию. Если клиент не авторизован,
      генерирует исключение TypeError
      '''
    def checker(*args, **kwargs):
        from lesson3.server.core import MessageProcessor
        from lesson3.common.variables import ACTION, PRESENCE
        if isinstance(args[0], MessageProcessor):
            found = False
            for arg in args:
                if isinstance(arg, socket.socket):
                    for client in args[0].names:
                        if args[0].names[client] == arg:
                            found = True

            for arg in args:
                if isinstance(arg, dict):
                    if ACTION in arg and arg[ACTION] == PRESENCE:
                        found = True
            if not found:
                raise TypeError
        return func(*args, **kwargs)

    return checker
